@@ -61,7 +61,7 @@ class CardstoriesResource(resource.Resource):
 
         # catch errors and dump a trace ...
         def failed(reason):
-            reason.printDetailedTraceback()
+            reason.printTraceback()
             body = reason.getTraceback()
             request.setResponseCode(http.INTERNAL_SERVER_ERROR)
             request.setHeader('content-type',"text/html")
@@ -75,6 +75,7 @@ class CardstoriesResource(resource.Resource):
             request.setHeader("content-type", 'application/json; charset="UTF-8"')
             request.write(content)
             request.finish()
+            return result
         d.addCallbacks(succeed, failed)
 
         return d
