@@ -85,17 +85,51 @@
             var ok = function(card) {
                 $this.create_write_sentence(player_id, card, root);
             };
-            var cards = $this.create_deck().map(function(card) {
-                return { 'value':card };
+            var cards = $this.create_deck();
+            $this.select_card(cards, ok, element);
+        },
+
+        select_card: function(cards, ok, element) {
+            var reset = function() {
+                $('.cardstories_card_bg', element).removeClass('cardstories_card_selected');
+                $(element).toggleClass('cardstories_card_selecting', true);
+            };
+            reset();
+            var confirm = function(card) {
+                $(element).toggleClass('cardstories_card_selecting', false);
+                $('.cardstories_card_confirm_ok', element).unbind('click').click(function() {
+                    reset();
+                    ok(card);
+                });
+                $('.cardstories_card_confirm_cancel', element).unbind('click').click(function() {
+                    reset();
+                });
+            };
+
+            $('.cardstories_cards_hand .cardstories_card_bg', element).each(function(index) {
+                var bg = $(this);
+                if(index < cards.length) {
+                    var card = cards[index];
+                    var c = 'cardstories_card cardstories_small_card' + card;
+                    bg.show();
+                    $('.cardstories_card', bg).
+                        attr('class', c).
+                        unbind('click').
+                        click(function() {
+                            bg.addClass('cardstories_card_selected');
+                            confirm(card);
+                        });
+                } else {
+                    bg.hide();
+                }
             });
-            return $this.select_cards(cards, ok, element);
         },
 
         create_write_sentence: function(player_id, card, root) {
             var $this = this;
             var element = $('.cardstories_create .cardstories_write_sentence', root);
             this.set_active(root, element);
-            $('.cardstories_card', element).attr('class', 'cardstories_card cardstories_card' + card + ' {card:' + card + '}');
+            $('.cardstories_card', element).attr('class', 'cardstories_card cardstories_wait_card' + card + ' {card:' + card + '}');
             var text = $('.cardstories_sentence', element);
             var submit = function() {
                 if($.trim($(text).val()) == $.data(text[0], 'placeholderValue')) {
@@ -162,11 +196,10 @@
                     $('.cardstories_submit').addClass('cardstories_submit_ready');
                     $('.cardstories_submit', element).unbind('click').click(function() {
                         var text = $('.cardstories_text', element).val();
-                        var invites = text.split(/\s+/).
-                                      filter(function(s) { return s !== ''; }).
-                                      map(function(s) {
-                                          return 'player_id=' + encodeURIComponent(s);
-                                        });
+                        var invites = $.map($.grep(text.split(/\s+/), function(s,i) { return s !== ''; }),
+                                            function(s,i) {
+                                                return 'player_id=' + encodeURIComponent(s);
+                                            });
                         $.cookie('CARDSTORIES_INVITATIONS', text);
                         $this.send_game(owner_id, game_id, element, 'action=invite&owner_id=' + owner_id + '&game_id=' + game_id + '&' + invites.join('&'));
                       });
@@ -175,12 +208,14 @@
                     $('.cardstories_submit').removeClass('cardstories_submit_ready');
                 }
             };
+            $('.cardstories_back', element).unbind('click').click(function() {
+                $this.reload(owner_id);
+            });
             load_text($('.cardstories_text', element));
+            $('textarea', element).focus();
             $('.cardstories_text', element).unbind('keyup').keyup(function () {
                 load_text($(this));
             });
-            var facebookUrl = $('#facebook_url').html().supplant({'GAME_URL': escape(this.permalink(owner_id, game_id, root))});
-            $('.cardstories_fb_invite', element).attr('src', facebookUrl);
         },
 
         poll_timeout: 300 * 1000, // must be identical to the --poll-timeout value 
@@ -206,7 +241,7 @@
                   if('timeout' in answer) {
                     $this.poll(request, root);
                   } else {
-                    $this.reload(request.player_id, request.game_id, root);
+                    $this.game_or_lobby(request.player_id, request.game_id, root);
                   }
                 }
               }
@@ -325,7 +360,11 @@
         },
 
         start_story: function(player_id, root) {
+            var $this = this;
             this.poll_discard(root);
+            $('.cardstories_go_lobby', root).unbind('click').click(function() {
+                $this.reload(player_id);
+            });
             this.create(player_id, root);
         },
 
@@ -404,7 +443,7 @@
             var voting = $('.cardstories_voting', element);
             voting.toggleClass('cardstories_ready', game.ready);
             if(game.ready) {
-                voting.click(function() {
+                voting.unbind('click').click(function() {
                     $this.send_game(player_id, game.id, element, 'action=voting&owner_id=' + player_id + '&game_id=' + game.id);
                 });
             }
@@ -412,7 +451,7 @@
             // Navigate to invite more friends, if desired
             //
             var invite_friends = $('.cardstories_invite_friends', element);
-            invite_friends.click(function() {
+            invite_friends.unbind('click').click(function() {
                 $.cookie('CARDSTORIES_INVITATIONS', null);
                 $this.advertise(player_id, game.id, root);
             });
@@ -420,22 +459,20 @@
             // display the cards picked by the current players
             //
             var players = game.players;
-            var waiting = element.metadata({type: "attr", name: "data"}).waiting;
-            var count = $('.cardstories_card', element).length;
-            var cards = [];
-            for(var i = 0; i < count; i++) {
-                var card;
-                if(i < players.length) {
-                    card = { 'value': players[i][3],
-                             'label': players[i][0] };
-                } else {
-                    card = { 'value': null,
-                             'label': waiting };
+            $('.cardstories_player_name', element).each(function(index) {
+                if(index < players.length) {
+                    $(this).text(players[index][0]);
                 }
-                cards.push(card);
-            }
-            var hand = $('.cardstories_cards_hand', element);
-            return this.display_or_select_cards(cards, undefined, hand);
+            });
+            $('.cardstories_cards_hand .cardstories_card', element).each(function(index) {
+                if(index < players.length && players[index][3] !== null) {
+                    var card = players[index][3];
+                    var c = 'cardstories_card cardstories_small_card' + card;
+                    $(this).attr('class', c);
+                } else {
+                    $(this).attr('class', 'cardstories_card cardstories_no_small_card');
+                }
+            });
         },
 
         invitation_pick: function(player_id, game, root) {
@@ -446,8 +483,7 @@
             var ok = function(card) {
                 $this.send_game(player_id, game.id, element, 'action=pick&player_id=' + player_id + '&game_id=' + game.id + '&card=' + card);
             };
-            var cards = game.self[2].map(function(card) { return {'value':card}; });
-            return $this.select_cards(cards, ok, element);
+            $this.select_card(game.self[2], ok, element);
         },
 
         invitation_pick_wait: function(player_id, game, root) {
@@ -462,100 +498,6 @@
             });
         },
 
-        select_cards: function(cards, ok, element) {
-            var confirm = $('.cardstories_card_confirm', element);
-            var middle = confirm.metadata({type: "attr", name: "data"}).middle;
-            var confirm_callback = function(card, index, nudge, cards_element) {
-                confirm.show();
-                var parent = confirm.parent('.cardstories_active');
-                parent.toggleClass('cardstories_card_confirm_right', index >= middle);
-                $('.cardstories_card_confirm_ok', confirm).unbind('click').click(function() {
-                    confirm.hide();
-                    ok(card);
-                    parent.removeClass('cardstories_card_confirm_right');
-                    nudge();
-                });
-                $('.cardstories_card_confirm_cancel', confirm).unbind('click').click(function() {
-                    confirm.hide();
-                    parent.removeClass('cardstories_card_confirm_right');
-                    nudge();
-                });
-            };
-            var hand = $('.cardstories_cards_hand', element);
-            return this.display_or_select_cards(cards, confirm_callback, hand);
-        },
-
-        display_or_select_cards: function(cards, select_callback, element) {
-            var meta = element.metadata({type: "attr", name: "data"});
-            var options = {
-                'active': meta.active,
-                'size': meta.size,
-                'distance': meta.distance
-            };
-            var template = $('.cardstories_card_template', element);
-            var dock = $('.cardstories_cards', element);
-
-            var deferred = $.Deferred();
-            options.onReady = function(is_ready) {
-                var links = $('a.cardstories_card', element);
-                var html = template.html();
-                var meta = template.metadata({type: "attr", name: "data"});
-                links.each(function(index) {
-                    var link = $(this);
-                    var card = cards[index];
-                    var card_file = meta.nocard;
-                    if(index < cards.length && card !== null && card.value !== null) {
-                        card_file = meta.card.supplant({'card': card.value});
-                    }
-                    var label = card && card.label ? card.label : '';
-                    link.html(html.supplant({ 'label': label }));
-                    var zindex = 3 * (links.length - index);
-                    link.css({zIndex: zindex});
-                    var background = $('.cardstories_card_background', link);
-                    var has_bg = meta.card_bg && meta.card_bg.length > 0;
-                    if(has_bg) {
-                        background.attr('src', meta.card_bg);
-                    } else if(background.attr('src') !== undefined) {
-                        background.removeAttr('src');
-                    }
-                    background.css({zIndex: links.length - index});
-                    var foreground = $('.cardstories_card_foreground', link);
-                    foreground.attr('src', card_file).css({zIndex: 2 * (links.length - index)});
-                    if(card) {
-                        link.toggleClass('cardstories_card_inactive', card.inactive !== undefined);
-                    }
-                    if(select_callback !== undefined && card && card.inactive === undefined) {
-                        link.metadata({type: "attr", name: "data"}).card = card.value;
-                        link.unbind('click').click(function() {
-                            if(!$('a.cardstories_card', element).hasClass('cardstories_card_selected')) {
-                                link.addClass('cardstories_card_selected');
-                                link.css({zIndex: 200});
-                                var nudge = function() {
-                                    link.removeClass('cardstories_card_selected');
-                                    link.css({zIndex: zindex});
-                                    if(has_bg) {
-                                        background.attr('src', meta.card_bg);
-                                    } else {
-                                        background.removeAttr('src');
-                                    }
-                                    dock.jqDock('nudge');
-                                };
-                                background.attr('src', meta.card_bg_selected);
-                                dock.jqDock('freeze');
-                                $(this).blur();
-                                select_callback.call(this, card.value, index, nudge, element);
-                            }
-                        });
-                    }
-                });
-                deferred.resolve(is_ready);
-            };
-
-            dock.jqDock(options);
-
-            return deferred;
-        },
-
         confirm_participate: false,
 
         invitation_participate: function(player_id, game, root) {
@@ -614,7 +556,7 @@
             $('.cardstories_sentence', element).text(game.sentence);
             var cards = game.board;
             $('.cardstories_card', element).each(function(index) {
-                var c = 'cardstories_card cardstories_card' + cards[index] + ' {card:' + cards[index] + '}';
+                var c = 'cardstories_card cardstories_wait_card' + cards[index] + ' {card:' + cards[index] + '}';
                 $(this).attr('class', c);
             });
         },
@@ -627,19 +569,10 @@
             var ok = function(card) {
                 $this.send_game(player_id, game.id, element, 'action=vote&player_id=' + player_id + '&game_id=' + game.id + '&card=' + card);
             };
-            var cards = [];
-            var picked = game.self[0];
-            var voted = game.self[1];
-            var titles = [];
-            for(var i = 0; i < game.board.length; i++) {
-                var card = { 'value': game.board[i] };
-                if(card.value == picked) {
-                    card.label = 'My Card';
-                    card.inactive = true;
-                }
-                cards.push(card);
-            }
-            return $this.select_cards(cards, ok, element);
+            $('.cardstories_self_card .cardstories_card', element).attr('class', 'cardstories_card cardstories_wait_card' + game.self[0]);
+            $this.select_card($.grep(game.board, function(card, index) {
+                return card != game.self[0];
+            }), ok, element);
         },
 
         vote_voter_wait: function(player_id, game, root) {
@@ -838,12 +771,11 @@
             var $this = this;
             var element = $('.cardstories_subscribe', root);
             $this.set_active(root, element);
-            validator = $(".cardstories_emailform", element).validate({
-                submitHandler: function(form) {
-                    var player_id = encodeURIComponent($('.cardstories_email', element).val());
-                    $.cookie('CARDSTORIES_ID', player_id);
-                    $this.game_or_lobby(player_id, game_id, root);        
-                }
+            validator = $(".cardstories_emailform", element).submit(function() {
+                var player_id = encodeURIComponent($('.cardstories_email', element).val());
+                $.cookie('CARDSTORIES_ID', player_id);
+                $this.game_or_lobby(player_id, game_id, root);
+                return true;
             });
 
             $('.cardstories_email', element).focus();
@@ -868,16 +800,16 @@
 
         credits: function(root) {
             var element = $('.cardstories_credits', root);
-            var long = $('.cardstories_credits_long', element);
+            var credits = $('.cardstories_credits_long', element);
             $('.cardstories_credits_short', element).click(function() {
-                long.show();
+                credits.show();
             });
-            $('.cardstories_credits_close', long).click(function() {
-                long.hide();
+            $('.cardstories_credits_close', credits).click(function() {
+                credits.hide();
             });
-            long.show(); // jScrollPane needs the element to be visible to calculate its height / width
-            $('.cardstories_credits_text', long).jScrollPane({showArrows: true});
-            long.hide();
+            credits.show(); // jScrollPane needs the element to be visible to calculate its height / width
+            $('.cardstories_credits_text', credits).jScrollPane({showArrows: true});
+            credits.hide();
         }
 
     };
@@ -894,13 +826,6 @@
         });
     };
 
-    $.fn.trigger_keypress = function(key_code) {
-        return $.event.trigger({ type : 'keypress', which : key_code });
-    };
-    $.fn.trigger_keydown = function(key_code) {
-        return $.event.trigger({ type : 'keypress', which : key_code });
-    };
-
     $(window).bind("beforeunload", function() {
         $.cardstories.error = $.cardstories.noop;
     });
