@@ -16,7 +16,7 @@
 //
 (function($) {
 
-  $.cardstories.skin = function(what, root) {
+  $.cardstories.skin = function(skin, root) {
     $(root).addClass('cardstories_root');
     var lobby = {'games': [[100, 'sentence100', 'invitation', 0],
                            [101, 'sentence101', 'vote', 1],
