@@ -182,7 +182,7 @@ test("subscribe", function() {
     equal($('#qunit-fixture .cardstories_subscribe.cardstories_active').length, 0);
     $.cardstories.email(game_id, $('#qunit-fixture .cardstories'));
     equal($('#qunit-fixture .cardstories_subscribe.cardstories_active').length, 1);
-    equal($.cookie('CARDSTORIES_ID'), null);
+    ok($.cookie('CARDSTORIES_ID') === "" || $.cookie('CARDSTORIES_ID') === null);
     $('#qunit-fixture .cardstories_subscribe .cardstories_email').val(player_id);
     // any ajax issued as indirect side effect of subscribing is ignored because it is
     // not a direct side effect
@@ -190,32 +190,14 @@ test("subscribe", function() {
     $('#qunit-fixture .cardstories_subscribe .cardstories_submit').submit();
     equal($.cookie('CARDSTORIES_ID').replace(/%40/g, "@"), player_id);
     $.cookie('CARDSTORIES_ID', null);
-    equal($.cookie('CARDSTORIES_ID'), null);
-});
-
-test("subscribe_validation_error", function() {
-    setup();
-    expect(3);
-
-    var player_id = 'PLAYER';
-    var game_id = undefined;
-    $.cookie('CARDSTORIES_ID', null);
-    $.cardstories.email(game_id, $('#qunit-fixture .cardstories'));
-    equal($.cookie('CARDSTORIES_ID'), null);
-    $('#qunit-fixture .cardstories_subscribe .cardstories_email').val(player_id);
-    // any ajax issued as indirect side effect of subscribing is ignored because it is
-    // not a direct side effect
-    $.cardstories.ajax = function(options) {};
-    $('#qunit-fixture .cardstories_subscribe .cardstories_submit').submit();
-    equal($('#qunit-fixture .cardstories_subscribe label.error').attr('for'), 'email');
-    equal($.cookie('CARDSTORIES_ID'), null);
+    ok($.cookie('CARDSTORIES_ID') === "" || $.cookie('CARDSTORIES_ID') === null);
 });
 
 test("widget subscribe", function() {
     setup();
     expect(3);
 
-    equal($.cookie('CARDSTORIES_ID'), null);
+    ok($.cookie('CARDSTORIES_ID') === "" || $.cookie('CARDSTORIES_ID') === null);
     equal($('#qunit-fixture .cardstories_subscribe.cardstories_active').length, 0);
     $('#qunit-fixture .cardstories').cardstories(undefined, undefined);
     equal($('#qunit-fixture .cardstories_subscribe.cardstories_active').length, 1);
@@ -309,12 +291,12 @@ test("create", function() {
 
     var player_id = 15;
     var game_id = 7;
-    var card;
     var sentence = 'SENTENCE';
 
     $.cardstories.ajax = function(options) {
         equal(options.type, 'POST');
-        equal(options.url, $.cardstories.url + '?action=create&owner_id=' + player_id + '&card=' + card);
+        var url = $.cardstories.url + '?action=create&owner_id=' + player_id + '&card=';
+        equal(options.url.indexOf(url), 0, url);
 	equal(options.data, 'sentence=' + sentence);
 
 	var game = {
@@ -331,27 +313,22 @@ test("create", function() {
 
     var element = $('#qunit-fixture .cardstories_create');
     equal($('.cardstories_pick_card.cardstories_active', element).length, 0, 'pick_card not active');
-    $.cardstories.
-        create(player_id, $('#qunit-fixture .cardstories')).
-        done(function(is_ready) {
-            equal($('.cardstories_pick_card.cardstories_active', element).length, 1, 'pick_card active');
-            equal($('.cardstories_write_sentence.cardstories_active', element).length, 0, 'sentence not active');
-            var first_card = $('.cardstories_card:nth(0)', element);
-            card = first_card.metadata({type: "attr", name: "data"}).card;
-            first_card.click();
-            $('.cardstories_card_confirm_ok', element).click();
-            equal($('.cardstories_write_sentence.cardstories_active', element).length, 1, 'sentence active');
-            ok($('.cardstories_sentence', element).attr('placeholder') !== undefined, 'placeholder is set');
-            equal($('.cardstories_sentence', element).attr('placeholder'), $('.cardstories_sentence', element).val());
-            $('.cardstories_write_sentence .cardstories_submit', element).submit();
-            $('.cardstories_write_sentence .cardstories_sentence', element).val(sentence);
-            $('.cardstories_write_sentence .cardstories_submit', element).submit();
-        });
+    $.cardstories.create(player_id, $('#qunit-fixture .cardstories'));
+    equal($('.cardstories_pick_card.cardstories_active', element).length, 1, 'pick_card active');
+    equal($('.cardstories_write_sentence.cardstories_active', element).length, 0, 'sentence not active');
+    var first_card = $('.cardstories_card:nth(0)', element);
+    first_card.click();
+    $('.cardstories_card_confirm_ok', element).click();
+    equal($('.cardstories_write_sentence.cardstories_active', element).length, 1, 'sentence active');
+    ok($('.cardstories_sentence', element).attr('placeholder') !== undefined, 'placeholder is set');
+    equal($('.cardstories_sentence', element).attr('placeholder'), $('.cardstories_sentence', element).val());
+    $('.cardstories_write_sentence .cardstories_submit', element).submit();
+    $('.cardstories_write_sentence .cardstories_sentence', element).val(sentence);
+    $('.cardstories_write_sentence .cardstories_submit', element).submit();
 });
 
 test("create on error", function() {
     setup();
-    stop();
     expect(1);
 
     var player_id = 15;
@@ -366,16 +343,12 @@ test("create on error", function() {
     };
 
     var element = $('#qunit-fixture .cardstories_create');
-    $.cardstories.
-        create(player_id, $('#qunit-fixture .cardstories')).
-        done(function(is_ready) {
-            var first_card = $('.cardstories_card:nth(0)', element);
-            first_card.click();
-            $('.cardstories_card_confirm_ok', element).click();
-            $('.cardstories_write_sentence .cardstories_sentence', element).val('SENTENCE');
-            $('.cardstories_write_sentence .cardstories_submit', element).submit();
-            start();
-        });
+    $.cardstories.create(player_id, $('#qunit-fixture .cardstories'));
+    var first_card = $('.cardstories_card:nth(0)', element);
+    first_card.click();
+    $('.cardstories_card_confirm_ok', element).click();
+    $('.cardstories_write_sentence .cardstories_sentence', element).val('SENTENCE');
+    $('.cardstories_write_sentence .cardstories_submit', element).submit();
 });
 
 test("widget lobby", function() {
@@ -507,8 +480,7 @@ test("invitation_owner_nobody_invited_yet", function() {
 
 test("invitation_owner", function() {
     setup();
-    stop();
-    expect(13);
+    expect(11);
 
     var player1 = 'player1';
     var card1 = 5;
@@ -530,7 +502,6 @@ test("invitation_owner", function() {
     $.cardstories.ajax = function(options) {
         equal(options.type, 'GET');
         equal(options.url, $.cardstories.url + '?action=voting&owner_id=' + player_id + '&game_id=' + game_id);
-        start();
     };
 
     $.cardstories.poll_ignore = function(ignored_request, ignored_answer, new_poll, old_poll) {
@@ -539,31 +510,25 @@ test("invitation_owner", function() {
     };
 
     equal($('#qunit-fixture .cardstories_invitation .cardstories_owner.cardstories_active').length, 0);
-    $.cardstories.
-        invitation(player_id, game, $('#qunit-fixture .cardstories')).
-        done(function(is_ready) {
-            equal($('#qunit-fixture .cardstories_invitation .cardstories_owner .cardstories_sentence').text(), sentence);
-            var cards = $('#qunit-fixture .cardstories_invitation .cardstories_owner .cardstories_cards');
-            equal($('.cardstories_card:nth(0) .cardstories_card_foreground', cards).attr('alt'), player1);
-            equal($('.cardstories_card:nth(0) .cardstories_card_foreground', cards).attr('src'), 'PATH/card0' + card1 + '.png');
-            equal($('.cardstories_card:nth(1) .cardstories_card_foreground', cards).attr('alt'), player2);
-            equal($('.cardstories_card:nth(1) .cardstories_card_foreground', cards).attr('src'), 'PATH/card-back.png');
-            equal($('.cardstories_card:nth(2) .cardstories_card_foreground', cards).attr('alt'), 'Waiting');
-            equal($('.cardstories_card:nth(2) .cardstories_card_foreground', cards).attr('src'), 'PATH/card-back.png');
-            equal($('#qunit-fixture .cardstories_invitation .cardstories_owner.cardstories_active').length, 1);
-            $('#qunit-fixture .cardstories_owner .cardstories_voting').click();
-        });
+    $.cardstories.invitation(player_id, game, $('#qunit-fixture .cardstories'));
+    equal($('#qunit-fixture .cardstories_invitation .cardstories_owner .cardstories_sentence').text(), sentence);
+    var owner = $('#qunit-fixture .cardstories_invitation .cardstories_owner');
+    equal($('.cardstories_player_name:nth(0)', owner).text(), player1);
+    ok($('.cardstories_card:nth(0)', owner).attr('class').indexOf('card' + card1) > 0, 'card ' + card1);
+    equal($('.cardstories_player_name:nth(1)', owner).text(), player2);
+    ok($('.cardstories_card:nth(1)', owner).attr('class').indexOf('no_small_card') > 0, 'no card');
+    equal($('#qunit-fixture .cardstories_invitation .cardstories_owner.cardstories_active').length, 1);
+    $('#qunit-fixture .cardstories_owner .cardstories_voting').click();
 });
 
 test("invitation_pick", function() {
     setup();
-    stop();
     expect(11);
 
     var player_id = 15;
     var game_id = 101;
     var picked = 5;
-    var cards = [1,2,3,4,picked,5];
+    var cards = [1,2,3,4,picked,6];
     var sentence = 'SENTENCE';
 
     $.cardstories.ajax = function(options) {
@@ -578,37 +543,27 @@ test("invitation_pick", function() {
     };
 
     equal($('#qunit-fixture .cardstories_invitation .cardstories_pick.cardstories_active').length, 0);
-    var element = $('#qunit-fixture .cardstories_invitation .cardstories_pick .cardstories_cards');
+    var element = $('#qunit-fixture .cardstories_invitation .cardstories_pick .cardstories_cards_hand');
 
-    var invitation_picked = function() {
-        //
-        // the poll is not inhibited when a card has already been picked
-        //
-        $.cardstories.poll_ignore = function(ignored_request, ignored_answer, new_poll, old_poll) {
-            equal(ignored_request.game_id, game_id, 'poll_ignore request game_id');
-            equal(new_poll, undefined, 'poll_ignore metadata not set');
-            $('.cardstories_card:nth(4)', element).click();
-            $('#qunit-fixture .cardstories_invitation .cardstories_card_confirm_ok').click();
-            start();
-        };
-
-        game.self[0] = picked;
-        $.cardstories.invitation(player_id, game, $('#qunit-fixture .cardstories'));
+    $.cardstories.invitation(player_id, game, $('#qunit-fixture .cardstories'));
+    equal($('#qunit-fixture .cardstories_invitation .cardstories_pick.cardstories_active').length, 1);    
+    equal($('#qunit-fixture .cardstories_invitation .cardstories_pick .cardstories_sentence').text(), sentence);
+    ok($('.cardstories_card:nth(0)', element).attr('class').indexOf('card' + cards[0]) > 0, 'card ' + cards[0]);
+    ok($('.cardstories_card:nth(3)', element).attr('class').indexOf('card' + cards[3]) > 0, 'card ' + cards[3]);
+    $('.cardstories_card:nth(4)', element).click();
+    $('#qunit-fixture .cardstories_invitation .cardstories_card_confirm_ok').click();
+    //
+    // the poll is not inhibited when a card has already been picked
+    //
+    $.cardstories.poll_ignore = function(ignored_request, ignored_answer, new_poll, old_poll) {
+        equal(ignored_request.game_id, game_id, 'poll_ignore request game_id');
+        equal(new_poll, undefined, 'poll_ignore metadata not set');
+        $('.cardstories_card:nth(4)', element).click();
+        $('#qunit-fixture .cardstories_invitation .cardstories_card_confirm_ok').click();
     };
 
-    $.cardstories.
-        invitation(player_id, game, $('#qunit-fixture .cardstories')).
-        done(function(is_ready) {
-            equal($('#qunit-fixture .cardstories_invitation .cardstories_pick.cardstories_active').length, 1);    
-            equal($('#qunit-fixture .cardstories_invitation .cardstories_pick .cardstories_sentence').text(), sentence);
-            equal($('.cardstories_card:nth(0) .cardstories_card_foreground', element).attr('src'), 'PATH/card0' + cards[0] + '.png');
-            equal($('.cardstories_card:nth(5) .cardstories_card_foreground', element).attr('src'), 'PATH/card0' + cards[5] + '.png');
-            $('.cardstories_card:nth(4)', element).click();
-            $('#qunit-fixture .cardstories_invitation .cardstories_card_confirm_ok').click();
-
-            window.setTimeout(invitation_picked, 50);
-        });
-
+    game.self[0] = picked;
+    $.cardstories.invitation(player_id, game, $('#qunit-fixture .cardstories'));
 });
 
 test("invitation_pick_wait", function() {
@@ -755,8 +710,7 @@ test("widget invitation", function() {
 
 test("vote_voter", function() {
     setup();
-    stop();
-    expect(18);
+    expect(14);
 
     var player_id = 15;
     var game_id = 101;
@@ -781,39 +735,31 @@ test("vote_voter", function() {
     equal($('.cardstories_card:nth(1) .cardstories_card_foreground', element).attr('alt'), undefined);
     equal($('#qunit-fixture .cardstories_vote .cardstories_voter.cardstories_active').length, 0);
 
-    var vote_voted = function() {
-        //
-        // the poll is not inhibited when a card has already been voted for
-        //
-        $.cardstories.poll_ignore = function(ignored_request, ignored_answer, new_poll, old_poll) {
-            equal(ignored_request.game_id, game_id, 'poll_ignore request game_id');
-            equal(new_poll, undefined, 'poll_ignore metadata not set');
-            $('.cardstories_card:nth(4)', element).click();
-            $('#qunit-fixture .cardstories_vote .cardstories_card_confirm_ok').click();
-            start();
-        };
-
-        game.self[1] = voted;
-        $.cardstories.vote(player_id, game, $('#qunit-fixture .cardstories'));
+    $.cardstories.vote(player_id, game, $('#qunit-fixture .cardstories'));
+    equal($('#qunit-fixture .cardstories_vote .cardstories_voter.cardstories_active').length, 1);
+    equal($('#qunit-fixture .cardstories_voter .cardstories_sentence').text(), sentence);
+    for(var i = 0, j = 0; i < board.length; i++) {
+        if(board[i] == picked) {
+            continue;
+        } else {
+            ok($('.cardstories_card:nth(' + j + ')', element).attr('class').indexOf('card' + board[i]) > 0, 'card ' + board[i]);
+            j++;
+        }
+    }
+    $('.cardstories_card:nth(3)', element).click();
+    $('#qunit-fixture .cardstories_vote .cardstories_card_confirm_ok').click();
+    //
+    // the poll is not inhibited when a card has already been voted for
+    //
+    $.cardstories.poll_ignore = function(ignored_request, ignored_answer, new_poll, old_poll) {
+        equal(ignored_request.game_id, game_id, 'poll_ignore request game_id');
+        equal(new_poll, undefined, 'poll_ignore metadata not set');
+        $('.cardstories_card:nth(3)', element).click();
+        $('#qunit-fixture .cardstories_vote .cardstories_card_confirm_ok').click();
     };
 
-    $.cardstories.
-        vote(player_id, game, $('#qunit-fixture .cardstories')).
-        done(function(is_ready) {
-            equal($('#qunit-fixture .cardstories_vote .cardstories_voter.cardstories_active').length, 1);
-            equal($('#qunit-fixture .cardstories_voter .cardstories_sentence').text(), sentence);
-            for(var i = 0; i < board.length; i++) {
-                equal($('.cardstories_card:nth(' + i + ') .cardstories_card_foreground', element).attr('src'), 'PATH/card0' + board[i] + '.png');
-            }
-            equal($('.cardstories_card:nth(0) .cardstories_card_foreground', element).attr('alt'), '', 'card0 alt was reset');
-            equal($('.cardstories_card:nth(1) .cardstories_card_foreground', element).attr('alt'), 'My Card', 'card1 alt was set');
-            equal($('.cardstories_card:nth(5) .cardstories_card_foreground', element).attr('src'), 'PATH/nocard.png');
-            $('.cardstories_picked', element).click(); // must do nothing
-            $('.cardstories_card:nth(4)', element).click();
-            $('#qunit-fixture .cardstories_vote .cardstories_card_confirm_ok').click();
-
-            window.setTimeout(vote_voted, 50);
-        });
+    game.self[1] = voted;
+    $.cardstories.vote(player_id, game, $('#qunit-fixture .cardstories'));
 });
 
 test("invitation_voter_wait", function() {
@@ -895,7 +841,7 @@ test("vote_anonymous", function() {
 
 test("vote_viewer", function() {
     setup();
-    expect(7);
+    expect(5);
 
     var player_id = 15;
     var game_id = 101;
@@ -918,8 +864,6 @@ test("vote_viewer", function() {
     $.cardstories.vote(player_id, game, $('#qunit-fixture .cardstories'));
     equal($('#qunit-fixture .cardstories_vote .cardstories_viewer.cardstories_active').length, 1);
     equal($('#qunit-fixture .cardstories_viewer .cardstories_sentence').text(), sentence);
-    equal($('#qunit-fixture .cardstories_viewer .cardstories_card1').metadata().card, 1);
-    equal($('#qunit-fixture .cardstories_viewer .cardstories_card7').metadata().card, 7);
 });
 
 test("vote_owner", function() {
@@ -1098,7 +1042,7 @@ test("results_board", function() {
 
 test("advertise", function() {
     setup();
-    expect(8);
+    expect(6);
     
     var owner_id = 15;
     var game_id = 100;
@@ -1130,13 +1074,6 @@ test("advertise", function() {
     ok(!$('.cardstories_submit', element).hasClass('cardstories_submit_ready'), 'button should be disabled');
     $('.cardstories_text', element).text('player1').keyup();
     ok($('.cardstories_submit', element).hasClass('cardstories_submit_ready'), 'button should be enabled');
-
-    // GAME_URL supplant
-    var root = $('#qunit-fixture .cardstories');    
-    var facebookUrl = $('#facebook_url').html().supplant({'GAME_URL': escape($.cardstories.permalink(owner_id, game_id, root))});
-    var src = $('.cardstories_fb_invite', element).attr('src');
-    ok(src.indexOf('GAME_URL') == -1, '{GAME_URL} supplant');
-    equal(src, facebookUrl);
   });
 
 test("refresh_lobby", function() {
@@ -1292,7 +1229,7 @@ test("poll_discard", function() {
 test("poll_ignore", function() {
     $.cardstories.poll_ignore = cardstories_original_poll_ignore;
 
-    if (console && console.log) {
+    if (typeof console !== "undefined" && typeof console.log !== "undefined") {
         expect(2);
 
         var log = console.log;
@@ -1313,7 +1250,7 @@ test("poll_ignore", function() {
 
 test("start_story", function() {
     setup();
-    expect(3);
+    expect(4);
 
     var player_id = 222;
     var root = $('#qunit-fixture .cardstories');
@@ -1325,6 +1262,11 @@ test("start_story", function() {
     $.cardstories.start_story(player_id, root);
     equal($('#qunit-fixture .cardstories_create .cardstories_pick_card.cardstories_active').length, 1, 'pick_card active');
     equal($(root).metadata().poll, poll + 1);
+    $.cardstories.reload = function(player_id_argument) {
+        equal(player_id, player_id_argument);
+    };
+    $('.cardstories_go_lobby', root).click();
+    $.cardstories.reload = cardstories_default_reload;
 });
 
 test("lobby_in_progress", function() {
@@ -1479,214 +1421,48 @@ test("poll", function() {
     $(root).metadata().poll = undefined;
   });
 
-var stabilize = function(e, x, y) {
-    var previous = 0;
-    while(previous != $(e).height()) {
-        previous = $(e).height();
-        $(e).trigger({ type: 'mousemove', pageX: x, pageY: y});
-    }
-    return previous;
-};
-
-test("display_or_select_cards move", function() {
+test("select_card", function() {
     setup();
-    stop();
-    expect(2);
+    expect(7);
 
     var root = $('#qunit-fixture .cardstories');
     root.addClass('cardstories_root');
-    $('.cardstories_create .cardstories_pick_card .cardstories_cards', root).show();
-    $.cardstories.set_active(root, $('.cardstories_create .cardstories_pick_card', root));
-    var element = $('.cardstories_create .cardstories_pick_card .cardstories_cards_hand', root);
-    var onReady = function(is_ready) {
-      var first = $('.cardstories_card:nth(1)', element);
-      var offset = $(first).offset();
-      var height = stabilize(first, offset.left, offset.top);
-      var width = $(first).width();
-      ok(stabilize(first, offset.left + width / 2, offset.top) > height, 'card is enlarged when moving toward the center');
-      equal(stabilize(first, offset.left, offset.top), height, 'card is resized to the same size when the mouse goes back to the original position');
-      start();
-    };
-    $.cardstories.
-        display_or_select_cards([{'value':1},{'value':2},{'value':3},{'value':4},{'value':5},{'value':6}],
-                                function() {}, 
-                                element).
-        done(onReady);
-  });
-
-test("display_or_select_cards select", function() {
-    setup();
-    stop();
-    expect(9);
-
-    var root = $('#qunit-fixture .cardstories');
-    var element = $('.cardstories_create .cardstories_cards_hand', root);
-    var label = 'LABEL';
-    var cards = [{'value':1},
-                 {'value':2,'label':label},
-                 {'value':3,'inactive':true},
-                 {'value':4},
-                 {'value':5},
-                 {'value':6}];
-    var selected = 1;
-    var inactive = 2;
-    var zindex;
-    var onReady = function(is_ready) {
-        var card_element = $('.cardstories_card', element).eq(1);
-        var foreground = $('.cardstories_card_foreground', card_element);
-        equal(foreground.attr('alt'), label);
-        zindex = card_element.css('z-index');
-        ok($('.cardstories_card', element).eq(inactive).hasClass('cardstories_card_inactive'), 'inactive class');
-        $('.cardstories_card', element).eq(inactive).click(); // noop
-        $('.cardstories_card', element).eq(selected).click();
-    };
-    var meta = $('.cardstories_card_template', element).metadata({type: "attr", name: "data"});
-    var select = function(card, index, nudge, element) {
-        equal(cards[index].value, card, 'selected card');
-        var link = $('.cardstories_card', element).eq(index);
-        var background = $('.cardstories_card_background', link);
-        ok(link.hasClass('cardstories_card_selected'), 'link has class cardstories_card_selected');
-        equal(link.css('z-index'), '200');
-        equal(background.attr('src'), meta.card_bg_selected);
-        nudge();
-        ok(!link.hasClass('cardstories_card_selected'), 'link no longer has class cardstories_card_selected');
-        equal(background.attr('src'), meta.card_bg);
-        equal(link.css('z-index'), zindex);
-        start();
-    };
-    $.cardstories.
-        display_or_select_cards(cards,
-                                select, 
-                                element).
-        done(onReady);
-  });
-
-test("display_or_select_cards select no bg", function() {
-    setup();
-    stop();
-    expect(4);
-
-    var root = $('#qunit-fixture .cardstories');
-    var element = $('.cardstories_create .cardstories_cards_hand', root);
-    var label = 'LABEL';
-    var cards = [{'value':1},
-                 {'value':2,'label':label},
-                 {'value':3},
-                 {'value':4},
-                 {'value':5},
-                 {'value':6}];
-    var selected = 1;
-    var onReady = function(is_ready) {
-        var background = $('.cardstories_card .cardstories_card_background', element).eq(1);
-        equal(background.attr('src'), undefined);
-        $('.cardstories_card', element).eq(selected).click();
-    };
-    var meta = $('.cardstories_card_template', element).metadata({type: "attr", name: "data"});
-    var select = function(card, index, nudge, element) {
-        var link = $('.cardstories_card', element).eq(index);
-        var background = $('.cardstories_card_background', link);
-        equal(background.attr('src'), meta.card_bg_selected);
-        nudge();
-        equal(background.attr('src'), undefined);
-        start();
-    };
-    var background = $('.cardstories_card_template .cardstories_card_background', element);
-    equal(background.attr('src'), 'templatebackground');
-    meta.card_bg = '';
-    $.cardstories.
-        display_or_select_cards(cards,
-                                select, 
-                                element).
-        done(onReady);
-  });
-
-test("select_cards ok", function() {
-    setup();
-    stop();
-    expect(2);
-
-    var root = $('#qunit-fixture .cardstories');
     var element = $('.cardstories_create .cardstories_pick_card', root);
     $.cardstories.set_active(root, element);
     var confirm = $('.cardstories_card_confirm', element);
-    var middle = confirm.metadata({type: "attr", name: "data"}).middle;
-    var cards = [{'value':1},{'value':2},{'value':3},{'value':4},{'value':5},{'value':6}];
+    var cards = [4,5,6];
     var selected = 5;
-    var onReady = function(is_ready) {
-        $('.cardstories_card', element).eq(selected).click();
-        $('.cardstories_card_confirm_ok', element).click();
-    };
+    var selected_index = 1;
     var ok_callback = function(card) {
-        equal(cards[selected].value, card, 'selected card');
-        ok(element.hasClass('cardstories_card_confirm_right'), 'selected card is to the right of the middle position defined in the HTML meta data');
-        start();
+        equal(cards[selected_index], card, 'selected card');
     };
-    $.cardstories.
-        select_cards(cards,
-                     ok_callback, 
-                     element).
-        done(onReady);
-  });
-
-test("select_cards cancel", function() {
-    setup();
-    stop();
-    expect(1);
-
-    var root = $('#qunit-fixture .cardstories');
-    var element = $('.cardstories_create', root);
-    var confirm = $('.cardstories_card_confirm', element);
-    var middle = confirm.metadata({type: "attr", name: "data"}).middle;
-    var cards = [{'value':1},{'value':2},{'value':3},{'value':4},{'value':5},{'value':6}];
-    var selected = 4;
-    var onReady = function(is_ready) {
-        $('.cardstories_card', element).eq(selected).click();
-        $('.cardstories_card_confirm_cancel', element).click();
-        ok(true);
-        start();
-    };
-    var ok_callback = function(card) {
-        ok(false, 'ok_callback unexpectedly called');
-    };
-    $.cardstories.
-        select_cards(cards,
-                     ok_callback, 
-                     element).
-        done(onReady);
-  });
-
-test("select_cards single", function() {
-    setup();
-    stop();
-
-    var root = $('#qunit-fixture .cardstories');
-    var element = $('.cardstories_create .cardstories_cards_hand', root);
-    var onReady = function(is_ready) {
-        var links = $('a.cardstories_card', element);
-        links.each(function(index) {
-            $(this).click();
-            var condition = $(this).hasClass('cardstories_card_selected') == index === 0;
-            var not = $(this).hasClass('cardstories_card_selected') ? '' : 'not';
-            ok(condition, 'Card ' + index + ' ' + not +  ' picked.');
-        });
-        start();
-    };
-    $.cardstories.
-        display_or_select_cards([{'value':1},{'value':2},{'value':3},{'value':4},{'value':5},{'value':6}],
-                                function() {},
-                                element).
-        done(onReady);
+    $.cardstories.select_card(cards, ok_callback, element);
+    var first = $('.cardstories_card_bg', element).eq(0);
+    equal(first.is(':visible'), true, 'first card is displayed');
+    var fifth = $('.cardstories_card_bg', element).eq(4);
+    equal(fifth.is(':visible'), false, 'fifth card is not displayed');
+    equal($('.cardstories_card_selected', element).length, 0, 'no card selected');
+    $('.cardstories_card', element).eq(selected_index).click();
+    equal($('.cardstories_card_selected', element).length, 1, 'one card selected');
+    ok(!$(element).hasClass('cardstories_card_selecting'), '!cardstories_card_selecting');
+    $('.cardstories_card_confirm_cancel', element).click();
+    ok($(element).hasClass('cardstories_card_selecting'), 'cardstories_card_selecting');
+    $('.cardstories_card', element).eq(selected_index).click();
+    $('.cardstories_card_confirm_ok', element).click();
   });
 
 test("create_deck", function() {
     setup();
-    expect(15);
+    expect(29);
     var deck = $.cardstories.create_deck();
+    var i;
     equal(deck.length, 7);
     while(deck.length > 0) {
         var card = deck.pop();
         equal(typeof card, "number");
-        equal(deck.indexOf(card), -1, 'duplicate of ' + card);
+        for(i = 0; i < deck.length; i++) {
+            ok(deck[i] != card, 'duplicate of ' + card);
+        }
     }
   });
 
@@ -1770,23 +1546,6 @@ test("poll on error", function() {
     $.cardstories.poll({}, root);
 });
 
-test("trigger_keypress, trigger_keydown helpers", function() {
-    expect(4);
-
-    var key_code = 101;
-    var trigger = $.event.trigger;
-
-    $.event.trigger = function(options) {
-        equal(options.type, 'keypress');
-        equal(options.which, key_code);
-    };
-
-    $('#qunit-fixture').trigger_keypress(key_code);
-    $('#qunit-fixture').trigger_keydown(key_code);
-
-    $.event.trigger = trigger;
-});
-
 test("onbeforeunload", function() {
     setup();
     expect(1);
